@@ -28,6 +28,7 @@
 # Revision Dates
 #    22-Dec-2009 (MPH) Creation
 #    17-May-2010 (MPH) Fixed 'iter_*' on empty items
+#     3-Aug-2010 (MPR) Fixed '__repr__' of 'Connection'
 #    revision-date
 #--
 import libcapi
@@ -117,12 +118,6 @@ class Sensor (Dir) :
     iterate over it's child sensors (e.g. DS2409) and 'find' to find other
     sensors by matching keyword arguments.
     """
-    def __init__ (self, path, capi) :
-        self._path   = path
-        self.capi = capi
-        self.cached  = True
-    # end def __init__
-
     def __repr__ (self) :
         return "<Sensor %s - %s>" % (self.path, self.get ("type"))
     # end def __repr__
@@ -287,6 +282,10 @@ class Connection (Sensor) :
         capi.init (port)
         super (Connection, self).__init__ ("/", capi)
     # end def __init__
+
+    def __repr__ (self) :
+        return "<Connection %s>" % (self.path)
+    # end def __repr__
 # end class Connection
 
 ### __END__ owfs
